[metadata]
name = Vsvpack
version = 0.0.2
author = PackTheCommand
author_email = packthecommand@gmail.com
description = A package for saving and reading simple Data like Setings
long_description = file: README.md
long_description_content_type = 
url = 
project_urls =
    Bug Tracker = 
classifiers =
    Programming Language :: Python :: 3
    License :: OSI Approved :: MIT License
    Operating System :: OS Independent

[options]
package_dir =
    = src
packages = find:
python_requires = >=3.6

[options.packages.find]
where = src